==> openvas-client_2.0.3.orig.tar.gz: openvas-client-2.0.3/nessus/html_output.h <==
/* NessusClient -- the Nessus Client
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */
 
#ifndef _NESSUSC_HTML_OUTPUT_H
#define _NESSUSC_HTML_OUTPUT_H
#include <glib.h>

int   arglist_to_html(struct arglist * , char * );
void  html_output_fprint_link(FILE* file, const char* key, const char*  item);
char* html_output_extract_xref(FILE* file, char* str, char* key);
char* html_output_convert_cr_to_html(char* str);
char* html_output_portname_to_ahref(char* name, char* hostname);
void  html_output_print_data_with_links(FILE* file, char* str, char* plugin_oid,
                      gboolean internal_link);

#endif

==> openvas-client_2.0.5.orig.tar.gz: openvas-client-2.0.5/nessus/html_output.h <==
/* NessusClient -- the Nessus Client
 * Copyright (C) 1998 Renaud Deraison
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * In addition, as a special exception, Renaud Deraison
 * gives permission to link the code of this program with any
 * version of the OpenSSL library which is distributed under a
 * license identical to that listed in the included COPYING.OpenSSL
 * file, and distribute linked combinations including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * this file, you may extend this exception to your version of the
 * file, but you are not obligated to do so.  If you do not wish to
 * do so, delete this exception statement from your version.
 */

#ifndef _NESSUSC_HTML_OUTPUT_H
#define _NESSUSC_HTML_OUTPUT_H
#include <glib.h>

typedef enum{
  ISSUE_TYPE_NONE,
  ISSUE_TYPE_FP,
  ISSUE_TYPE_NOTE,
  ISSUE_TYPE_WARN,
  ISSUE_TYPE_HOLE,
  ISSUE_TYPE_LAST
} issue_type;

int   arglist_to_html (struct arglist * , char * );
int   html_output_from_arg (struct arglist * , char * , gboolean, gboolean);
void  html_output_fprint_link(FILE* file, const char* key, const char*  item);
char* html_output_extract_xref(FILE* file, char* str, char* key);
char* html_output_convert_cr_to_html(char* str);
char* html_output_portname_to_ahref(char* name, char* hostname);
void  html_output_print_data_with_links(FILE* file, char* str, char* plugin_oid,
                      gboolean internal_link);

#endif
